@@ -1,4 +1,4 @@
-from . import codebuild, codepipeline, iam
+from . import codebuild, codepipeline, iam, logs
 
 
 def generate(config):
@@ -6,6 +6,10 @@ def generate(config):
 
     resources = {}
 
+    log_group = logs.log_group(config)
+    if log_group:
+        resources.update(log_group.definition)
+
     definition, codebuild_role_logical_name = iam.codebuild_role(config)
     resources.update(definition)
 
